@@ -1,6 +1,6 @@
 package Log::Any::Adapter::JSON;
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 use strict;
 use warnings;
@@ -93,6 +93,11 @@ sub _prepare_log_entry {
     for my $item ( @items ) {
 
         if ( ref($item) eq 'HASH' ) {
+            # special handling for Log::Any's context hash
+            if ( $item->{context} ) {
+                $log_entry{context} = delete $item->{context};
+            }
+
             if ( ! $seen_href ) {
                 for my $key ( keys %{ $item } ) {
                     if ( $key =~ /^(?:time|level|category|message)$/ ) {
@@ -166,7 +171,7 @@ __END__
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =encoding utf8
 
@@ -291,6 +296,14 @@ Output is a B<single string> with JSON like:
       "tracker":42
     }
 
+Reserved key names that may not be used in the first hashref include:
+
+  * category
+  * context
+  * level
+  * message
+  * time
+
 =head2 Additional hashrefs and arrayrefs
 
   $log->debug('the message', { tracker => 42 }, { foo => 'bar'});
